%
%   This function transforms back an interpolant f(u) to f(z) when
%
%            az + b                   b - du
%       u = --------     <==>    z = --------   (ad - bc != 0)
%            cz + d                   cu - a
%
%   Input:  domaintrans  -  Transformation parameters
%           interpolant  -  Interpolating function
%
%   Output: interpolantnew  -  New interpolating function
%
function interpolantnew = bilineardomain(domaintrans,interpolant)

if length(interpolant.b) ~= length(interpolant.a)
    disp('In bilineardomain: interpolant''s numerator and denominator')
    disp('                   have different degree')
    return
end

n = length(interpolant.a) - 1;

abvec{1} = 1;
cdvec{1} = 1;
for k = 1:n
    abvec{k+1} = conv(abvec{k},[domaintrans.a domaintrans.b]);
    cdvec{k+1} = conv(cdvec{k},[domaintrans.c domaintrans.d]);
end

betanew = zeros(1,n+1);
alphanew = betanew;

for k = 1:n+1
    temppoly = conv(abvec{k},cdvec{end+1-k});
    betanew = betanew + interpolant.b(k)*temppoly;
    alphanew = alphanew + interpolant.a(k)*temppoly;
end

interpolantnew = getinterpolant(fliplr(betanew),fliplr(alphanew));