%
%   This function transforms back an interpolant g(z) to f(z) for
%    the bilinear transformation
%
%               af(z) + b                      b - dg(z)
%       g(z) = -----------     <-->    f(z) = ----------- 
%               cf(z) + d                      cg(z) - a
%
%                      (ad - bc != 0)
%
%       Input: a,b,c,d - transformation parameters
%              beta    - increasing numerator polynomial
%              alpha   - increasing denominator polynomial
%
%                        betan z^n + ... + beta1 z + beta0 
%               g(z) = --------------------------------------
%                       alphan z^n + ... + alpha1 z + alpha0 
%
%       Output: betanew  - increasing numerator polynomial
%               alphanew - increasing denominator polynomial
%
function interpolantnew = bilinearrange(rangetrans,interpolant)

if length(interpolant.b) ~= length(interpolant.a)
    disp('In bilinearrange: interpolant''s numerator and denominator')
    disp('                  have different degree')
    return
end

betanew = - rangetrans.d*interpolant.b + rangetrans.b*interpolant.a;
alphanew = rangetrans.c*interpolant.b - rangetrans.a*interpolant.a;

interpolantnew = getinterpolant(betanew,alphanew);