%
%   This function calculates the beta polynomial of the interpolant
%    f given the polynomial alpha and the vector muvec.
%
%               b(z)
%       f(z) = ------
%               a(z)
%
%                       a * b* + b * a*      mu(z)
%       f(z) + f*(z) = ----------------- = ---------
%                            a * a*          a * a*
%
%   Input:  alpha - coefficients of a
%           muvec - coefficients of mu
%               where alpha = [ alpha0 alpha1 ... alphan ]
%                     mu = [ mu0 mu1 ... mun ]
%                     mu(z) = mu0 + mu1 (z + z^-1) + ...
%
%   Output: beta - coefficients of b
%               where beta = [ beta0 beta1 ... betan ]
%
function beta = getbeta(alpha,muvec)

Talpha = hankel(alpha) + toeplitz([alpha(1) zeros(1,length(alpha)-1)],alpha);
beta = (Talpha\muvec)';
