%
%   This function returns an interpolant
%
%            b(z)     bn z^n + ... + b0
%       f = ------ = -------------------
%            a(z)     an z^n + ... + a0
%
%   Input: b - [ b0 b1 ... bn ] (increasing)
%          a - [ a0 a1 ... an ] (increasing)
%
%   Output: interpolant
%
function interpolant = getinterpolant(b,a)

%
%   Remove coefficients smaller than 1e-10
%
a(find(a < 1e-10 & a > -1e-10)) = 0;
b(find(b < 1e-10 & b > -1e-10)) = 0;

%
%   Normalize
%
a = a / b(max(find(b~=0)));
b = b / b(max(find(b~=0)));

%
%   Add zeros to same length
%
if length(a) < length(b)
    a = [ a zeros(1,length(b)-length(a)) ];
elseif length(a) > length(b)
    b = [ b zeros(1,length(a)-length(b)) ];
end

interpolant.b = b;
interpolant.a = a;
interpolant.zeros = roots(fliplr(b))';
interpolant.poles = roots(fliplr(a))';
