%
%   This function determine the Pick matrix for the scalar multiple
%    (derivative) Nevanlinna-Pick / Caratheodory interpolation 
%    problems
%
%   Input: interdata - interpolation data set
%
%   Output: P - the Pick matrix
%
function P = getpickmatrix(interdata)

z = interdata.z;
w = interdata.w;
mw = interdata.mw;
A = [];
bb = [];
W = [];

for j = 1:length(z)
    if mw(j) == 1
        Asub = z(j);
        bsub = 1;
    else
        Asub = toeplitz([z(j) 1 zeros(1,mw(j)-2)],[z(j) zeros(1,mw(j)-1)]);
        bsub = [1 zeros(1,mw(j)-1)]';
    end
    
    Wsub = toeplitz(w{j},[w{j}(1) zeros(1,mw(j)-1)]);
    A = blkdiag(A,Asub);
    bb = [bb; bsub];
    W = blkdiag(W,Wsub);
end

E = dlyap(A,bb*bb');
P = W*E+E*W';
