%
%   This function calculates the gradient of g_rho (or g~_rho)
%    at the point (alpha, mu)
%
%   Input: alpha - [ alpha0 alpha1 ... alphan ]
%          muvec - [ mu0 mu1 ... mun ]'
%          tau   - [ tau0 tau1 ... taun ]
%          K     - modified pick matrix
%
%       where alpha(z) = alpha0 + alpha1 z + ... + alphan z^n
%             mu(z) = mu0 + mu1 (z + z^-1) + ... + mun (z^n + z^-n)
%             tau(z) = tau0 + tau1 z + ... + taun z^n
%
%   Output: grad - gradient
%
function grad = grad3(alpha,muvec,tau,K)

n = length(alpha) - 1;
muvec(1) = muvec(1) / 2;

alphatau = conv(alpha,tau);  % Increasing
phat = covar2(1,alphatau,2*n);

p = (toeplitz(phat(1:n+1)) + hankel(phat(1:n+1), ...
    phat(n+1:2*n+1))) * muvec;
grad = 2 * (K - toeplitz(p)) * alpha(:);
